﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
	[TestClass]
	public class ClicksByHashTest
	{
		private const string ValidHashGoogle = "a5N8n6";
		private const string ValidHashYoutube = "bd7dYa";

		[TestMethod]
		public void TestValidHash()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var click = client.ClicksByHash(ValidHashGoogle);

			// Assert
			Assert.IsTrue(click.UserClicks > 0);
			Assert.IsTrue(click.GlobalClicks > 0);
		}

		[TestMethod]
		public void TestMultipleValidHashes()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var hashes = new[] { ValidHashGoogle, ValidHashYoutube };
			var clicks = client.ClicksMultiple(null, hashes);

			// Assert
			Assert.AreEqual(2, clicks.Count());
			foreach (var click in clicks)
			{
				Assert.IsTrue(click.UserClicks > 0);
				Assert.IsTrue(click.GlobalClicks > 0);
			}
		}

		[TestMethod]
		[ExpectedException(typeof(BitlyResultException))]
		public void TestInvalidHash()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var click = client.ClicksByHash("wwwgooogledk");
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestEmptyHash()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var click = client.ClicksByHash(string.Empty);
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestTooManyHashes()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var tooManyHashes = Enumerable.Repeat(ValidHashGoogle, BitlyClient.MaximumParameters + 1);

			// Act
			var clicks = client.ClicksMultiple(null, tooManyHashes);
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestNoHashes()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var noHashes = new string[0];

			// Act
			var clicks = client.ClicksMultiple(null, noHashes);
		}
	}
}
