﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
	[TestClass]
	public class ClicksByShortUrlTest
	{
		private const string ValidShortUrlGoogle = "http://bit.ly/a5N8n6";
		private const string ValidShortUrlYoutube = "http://bit.ly/bd7dYa";

		[TestMethod]
		public void TestValidUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var click = client.ClicksByShortUrl(ValidShortUrlGoogle);

			// Assert
			Assert.IsTrue(click.UserClicks > 0);
			Assert.IsTrue(click.GlobalClicks > 0);
		}

		[TestMethod]
		public void TestMultipleValidShortUrles()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var shortUrls = new[] { ValidShortUrlGoogle, ValidShortUrlYoutube };
			var clicks = client.ClicksMultiple(shortUrls, null);

			// Assert
			Assert.AreEqual(2, clicks.Count());
			foreach (var click in clicks)
			{
				Assert.IsTrue(click.UserClicks > 0);
				Assert.IsTrue(click.GlobalClicks > 0);
			}
		}

		[TestMethod]
		[ExpectedException(typeof(BitlyResultException))]
		public void TestInvalidDomain()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			client.ClicksByShortUrl("http://www.google.dk");

			// Assert
		}

		[TestMethod]
		[ExpectedException(typeof(BitlyResultException))]
		public void TestInvalidShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var click = client.ClicksByShortUrl("http://bit.ly/wwwgoogledk");
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestEmptyShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var click = client.ClicksByShortUrl(string.Empty);
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestTooManyShortUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var tooManyShortUrls = Enumerable.Repeat(ValidShortUrlGoogle, BitlyClient.MaximumParameters + 1);

			// Act
			var clicks = client.ClicksMultiple(tooManyShortUrls, null);
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestNoShortUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var noShortUrls = new string[0];

			// Act
			var clicks = client.ClicksMultiple(noShortUrls, null);
		}
	}
}
