﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
    [TestClass]
    public class ExpandHashTest
    {
        private const string ValidHashGoogle = "a5N8n6";
        private const string CorrespondingLongUrlGoogle = "http://www.google.dk";
		private const string ValidHashYoutube = "bd7dYa";
		private const string CorrespondingLongUrlYoutube = "http://www.youtube.com";

        [TestMethod]
        public void TestResultIsValidUrl()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var result = client.ExpandHash(ValidHashGoogle);

            // Assert
            Assert.AreEqual(CorrespondingLongUrlGoogle, result.LongUrl);
        }

		[TestMethod]
		public void TestMultipleResultIsValidUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var hashes = new[] {ValidHashGoogle, ValidHashYoutube};
			var results = client.ExpandMultiple(null, hashes).ToArray();

			// Assert
			Assert.AreEqual(2, results.Length);
			Assert.AreEqual(CorrespondingLongUrlGoogle, results[0].LongUrl);
			Assert.AreEqual(CorrespondingLongUrlYoutube, results[1].LongUrl);
		}

        [TestMethod]
        [ExpectedException(typeof(BitlyResultException))]
        public void TestInvalidHash()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var longUrl = client.ExpandHash("wwwgooogledk");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestEmptyHash()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var longUrl = client.ExpandHash(string.Empty);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestTooManyHashes()
        {
            // Arrange
            var client = Configuration.CreateClient();
            var tooManyHashes = Enumerable.Repeat(ValidHashGoogle, BitlyClient.MaximumParameters + 1);

            // Act
            var longUrls = client.ExpandMultiple(null, tooManyHashes);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestNoHashes()
        {
            // Arrange
            var client = Configuration.CreateClient();
            var noHashes = new string[0];

            // Act
            var longUrls = client.ExpandMultiple(null, noHashes);
        }
    }
}
