﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
	[TestClass]
	public class InfoShortUrlTest
	{
		private const string ValidShortUrlGoogle = "http://bit.ly/a5N8n6";
		private const string ValidShortUrlYoutube = "http://bit.ly/bd7dYa";

		private const string CorrespondingTitleGoogle = "Google";
		private const string CorrespondingCreatedByGoogle = "bugmenot123";

		private const string CorrespondingTitleYoutube = "YouTube"; // Not exactly actually, their title is somewhat troublesome due to linebreak.
		private const string CorrespondingCreatedByYoutube = "bugmenot123";

		[TestMethod]
		public void TestValidUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var info = client.InfoByShortUrl(ValidShortUrlGoogle);

			// Assert
			Assert.AreEqual(CorrespondingTitleGoogle, info.Title);
			Assert.AreEqual(CorrespondingCreatedByGoogle, info.CreatedBy);
		}

		[TestMethod]
		public void TestMultipleValidShortUrles()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var shortUrls = new[] { ValidShortUrlGoogle, ValidShortUrlYoutube };
			var infos = client.InfoMultiple(shortUrls, null).ToArray();

			// Assert
			Assert.AreEqual(2, infos.Length);

			Assert.AreEqual(CorrespondingTitleGoogle, infos[0].Title);
			Assert.AreEqual(CorrespondingCreatedByGoogle, infos[0].CreatedBy);

			Assert.IsTrue(infos[1].Title.StartsWith(CorrespondingTitleYoutube));
			Assert.AreEqual(CorrespondingCreatedByYoutube, infos[1].CreatedBy);
		}

		[TestMethod]
		[ExpectedException(typeof(BitlyResultException))]
		public void TestInvalidDomain()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			client.InfoByShortUrl("http://www.google.dk");

			// Assert
		}

		[TestMethod]
		[ExpectedException(typeof(BitlyResultException))]
		public void TestInvalidShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var info = client.InfoByShortUrl("http://bit.ly/wwwgoogledk");
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestEmptyShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var info = client.InfoByShortUrl(string.Empty);
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestTooManyShortUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var tooManyShortUrls = Enumerable.Repeat(ValidShortUrlGoogle, BitlyClient.MaximumParameters + 1);

			// Act
			var infos = client.InfoMultiple(tooManyShortUrls, null);
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestNoShortUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var noShortUrls = new string[0];

			// Act
			var infos = client.InfoMultiple(noShortUrls, null);
		}
	}
}
