﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
    [TestClass]
    public class LoginTest
    {
        [TestMethod]
        [ExpectedException(typeof(BitlyResultException))]
        public void TestInvalidLogin()
        {
            // Arrange
            var client = new BitlyClient("foo", Configuration.ApiKey);

            // Act
            var shortUrl = client.Shorten("http://www.google.dk");
        }

        [TestMethod]
        [ExpectedException(typeof(BitlyResultException))]
        public void TestInvalidApiKey()
        {
            // Arrange
            var client = new BitlyClient(Configuration.Login, "foo");

            // Act
            var shortUrl = client.Shorten("http://www.google.dk");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestEmptyLogin()
        {
            // Arrange
            var client = new BitlyClient(string.Empty, Configuration.ApiKey);

            // Act
            var shortUrl = client.Shorten("http://www.google.dk");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestEmptyApiKey()
        {
            // Arrange
            var client = new BitlyClient(Configuration.Login, string.Empty);

            // Act
            var shortUrl = client.Shorten("http://www.google.dk");
        }
    }
}
