﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
	[TestClass]
	public class LookupTest
	{
		private const string ValidLongUrlGoogle = "http://www.google.dk";
		private const string CorrespondingShortUrlGoogle = "http://bit.ly/18IpT1";
		private const string ValidLongUrlYoutube = "http://www.youtube.com";
		private const string CorrespondingShortUrlYoutube = "http://bit.ly/oSSZ2";

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestNoUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var noUrls = new string[0];

			// Act
			client.Lookup(noUrls);

			// Assert
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestTooManyUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();
			var tooManyUrls = Enumerable.Repeat(ValidLongUrlGoogle, BitlyClient.MaximumParameters + 1);

			// Act
			client.Lookup(tooManyUrls);

			// Assert
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestEmptyUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			client.Lookup(string.Empty);

			// Assert
		}

		[TestMethod]
		[ExpectedException(typeof(ArgumentException))]
		public void TestInvalidUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			client.Lookup("foo.bar.test");

			// Assert
		}

		[TestMethod]
		[ExpectedException(typeof(BitlyResultException))]
		public void TestNonBitlyUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			client.Lookup("http://www.foo.bar.test");

			// Assert
		}

		[TestMethod]
		public void TestValidUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var lookupResult = client.Lookup(ValidLongUrlGoogle);

			// Assert
			Assert.AreEqual(CorrespondingShortUrlGoogle, lookupResult.ShortUrl);
		}

		[TestMethod]
		public void TestMultipleValidUrls()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var longUrls = new[] { ValidLongUrlGoogle, ValidLongUrlYoutube };
			var lookupResults = client.Lookup(longUrls).ToArray();

			// Assert
			Assert.AreEqual(2, lookupResults.Length);
			Assert.AreEqual(CorrespondingShortUrlGoogle, lookupResults[0].ShortUrl);
			Assert.AreEqual(CorrespondingShortUrlYoutube, lookupResults[1].ShortUrl);
		}
	}
}
