﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net.Exceptions;

namespace Bitly.Net.Test.Tests
{
	[TestClass]
	public class ReferrerTest
	{
		private const string ValidShortUrlGoogle = "http://bit.ly/a5N8n6";
		private const string ValidHashGoogle = "a5N8n6";
		

		[ExpectedException(typeof(ArgumentException))]
		[TestMethod]
		public void TestNoHash()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var result = client.ReferrersHash(string.Empty);
		}

		[ExpectedException(typeof(ArgumentException))]
		[TestMethod]
		public void TestNoShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var result = client.ReferrersShortUrl(string.Empty);
		}

		[ExpectedException(typeof(BitlyResultException))]
		[TestMethod]
		public void TestInvalidHash()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var result = client.ReferrersHash("wwwgoogledk");
		}

		[ExpectedException(typeof(BitlyResultException))]
		[TestMethod]
		public void TestInvalidShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var result = client.ReferrersShortUrl("http://bit.ly/wwwgoogledk");
		}

		[TestMethod]
		public void TestValidHash()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var result = client.ReferrersHash(ValidHashGoogle);

			// Assert
			var directStat = result.Referrers.First(referrer => referrer.Referrer == "direct");
			Assert.IsNotNull(directStat);
			Assert.IsTrue(directStat.Clicks > 0);
		}

		[TestMethod]
		public void TestValidShortUrl()
		{
			// Arrange
			var client = Configuration.CreateClient();

			// Act
			var result = client.ReferrersShortUrl(ValidShortUrlGoogle);

			// Assert
			var directStat = result.Referrers.First(referrer => referrer.Referrer == "direct");
			Assert.IsNotNull(directStat);
			Assert.IsTrue(directStat.Clicks > 0);
		}
	}
}
