﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using Bitly.Net.Test.Utilities;
using Ckode.Bitly.Net;
using Ckode.Bitly.Net.Exceptions;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Bitly.Net.Test.Tests
{
    [TestClass]
    public class ShortenTest
    {
        private const string ValidLongUrl = "http://www.google.dk";
		private const string CorrespondingGlobalHash = "18IpT1";

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestInvalidXLogin()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var shortUrl = client.Shorten(ValidLongUrl, null, null, "someKey");

            // Assert
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestInvalidXApiKey()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var shortUrl = client.Shorten(ValidLongUrl, null, "somelogin", string.Empty);

            // Assert
        }

        [TestMethod]
        [ExpectedException(typeof(BitlyResultException))]
        public void TestValidYetUnknownDomain() // It's valid rule-wise, however it doesn't exist at bit.ly
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var shortUrl = client.Shorten(ValidLongUrl, "foo.dk");

            // Assert
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestInvalidDomain()
        {
            // Arrange
            var client = Configuration.CreateClient();
            var longDomain = string.Join(string.Empty, Enumerable.Repeat("s", 16));

            // Act
            var shortUrl = client.Shorten(ValidLongUrl, longDomain);

            // Assert
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestInvalidWWWLongUrl()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var shortUrl = client.Shorten("www.google.dk");

            // Assert
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestInvalidNonWWWLongUrl()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var shortUrl = client.Shorten("google.dk");

            // Assert
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void TestEmptyLongUrl()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var longUrl = client.Shorten(string.Empty);
        }

        [TestMethod]
        public void TestResultIsSameGlobalHash()
        {
            // Arrange
            var client = Configuration.CreateClient();

            // Act
            var result = client.Shorten(ValidLongUrl);

            // Assert
            Assert.AreEqual(CorrespondingGlobalHash, result.GlobalHash);
        }
    }
}
