﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Collections.Generic;
using Ckode.Bitly.Net.Request;
using Ckode.Bitly.Net.Validation;
using Ckode.Bitly.Net.Exceptions;

namespace Ckode.Bitly.Net.Functions
{
	internal class ReferrersFunction : IFunction
	{
		private string hash, shortUrl;
		private ReferrersFunction()
		{ 
		}

		public static ReferrersFunction CreateWithHash(string hash, IValidator validator)
		{
			if (string.IsNullOrEmpty(hash))
				throw ExceptionFactory.CreateMissingArgumentException("hash");

			if (!validator.IsValidHash(hash))
				throw ExceptionFactory.CreateInvalidHashException(hash);

			return new ReferrersFunction()
			{
				hash = hash
			};
		}

		public static ReferrersFunction CreateWithShortUrl(string shortUrl, IValidator validator)
		{
			if (string.IsNullOrEmpty(shortUrl))
				throw ExceptionFactory.CreateMissingArgumentException("shortUrl");

			if (!validator.IsValidShortUrl(shortUrl))
				throw ExceptionFactory.CreateInvalidShortUrlException(shortUrl);

			return new ReferrersFunction()
			{
				shortUrl = shortUrl
			};
		}

		public FunctionName Function
		{
			get { return FunctionName.Referrers; }
		}

		public HttpRequest CreateRequest()
		{
			var request = new HttpGetRequest();

			if (!string.IsNullOrEmpty(shortUrl))
				request.AddParameter(ParameterNames.ShortUrl, shortUrl);
			if (!string.IsNullOrEmpty(hash))
				request.AddParameter(ParameterNames.Hash, hash);

			return request;
		}
	}
}
