﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Request;
using Ckode.Bitly.Net.Validation;

namespace Ckode.Bitly.Net.Functions
{
	internal class ShortenFunction : IFunction
	{
		private readonly string longUrl;
		private readonly string domain;
		private readonly string xLogin;
		private readonly string xApiKey;

		public ShortenFunction(string longUrl, string domain, string xLogin, string xApiKey, IValidator validator)
		{
			if (!validator.IsValidUrl(longUrl))
				throw ExceptionFactory.CreateInvalidLongUrlException(longUrl);
			this.longUrl = ModifyQueryString(longUrl);

			if (!validator.IsValidDomain(domain, true))
				throw ExceptionFactory.CreateInvalidDomainException(domain);
			this.domain = domain;

			if (!validator.IsValidXUser(xLogin, xApiKey))
				throw ExceptionFactory.CreateInvalidXUserException(xLogin, xApiKey);
			this.xLogin = xLogin;
			this.xApiKey = xApiKey;
		}

		private static string ModifyQueryString(string longUrl)
		{
			return longUrl.Replace("?", "/?"); // Bit.ly requirement: http://code.google.com/p/bitly-api/wiki/ApiDocumentation#/v3/shorten
		}

		public FunctionName Function
		{
			get { return FunctionName.Shorten; }
		}

		public HttpRequest CreateRequest()
		{
			var request = new HttpGetRequest();

			request.AddParameter(ParameterNames.LongUrl, longUrl);

			if (!string.IsNullOrEmpty(domain))
				request.AddParameter(ParameterNames.Domain, domain);

			if (!string.IsNullOrEmpty(xLogin) && !string.IsNullOrEmpty(xApiKey))
			{
				request.AddParameter(ParameterNames.XLogin, xLogin);
				request.AddParameter(ParameterNames.XApiKey, xApiKey);
			}

			return request;
		}
	}
}
