﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Request;
using Ckode.Bitly.Net.Validation;

namespace Ckode.Bitly.Net.Functions
{
	internal class ValidateFunction : IFunction
	{
		private readonly string login;
		private readonly string apiKey;

		public ValidateFunction(string login, string apiKey, IValidator validator)
		{
			if (!validator.IsValidLogin(login))
				throw ExceptionFactory.CreateMissingArgumentException("login");
			this.login = login;

			if (!validator.IsValidApiKey(apiKey))
				throw ExceptionFactory.CreateMissingArgumentException("apiKey");
			this.apiKey = apiKey;
		}

		public FunctionName Function
		{
			get { return FunctionName.Validate; }
		}

		public HttpRequest CreateRequest()
		{
			var request = new HttpGetRequest();

			request.AddParameter(ParameterNames.XLogin, login);
			request.AddParameter(ParameterNames.XApiKey, apiKey);
			return request;
		}
	}
}
