﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Net;
using System.Text;

namespace Ckode.Bitly.Net.Request
{
	/// <summary>
	/// Simple wrapper for generating POST requests.
	/// </summary>
	internal class HttpPostRequest : HttpRequest
	{
		/// <summary>
		/// Gets or sets the Encoding of the parameters to be sent.
		/// </summary>
		/// <returns>The encoding used for the parameters. The default value is UTF-8.</returns>
		public Encoding Encoding { get; set; }

		/// <summary>
		/// Gets or sets the value of the Content-type HTTP header.
		/// </summary>
		/// <returns>The value of the Content-type HTTP header. The default value is application/x-www-form-urlencoded.</returns>
		public string ContentType { get; set; }

		public HttpPostRequest()
		{
			Encoding = Encoding.UTF8;
			ContentType = "application/x-www-form-urlencoded";
		}

		protected override WebRequest CreateRequest()
		{
			var parameterString = BuildParameterString();
			var data = Encoding.GetBytes(parameterString);

			var request = WebRequest.Create(Url) as HttpWebRequest;
			request.ContentType = ContentType;
			request.Method = "POST";
			request.ContentLength = data.Length;
			using (var requestStream = request.GetRequestStream())
			{
				requestStream.Write(data, 0, data.Length);
			}
			return request;
		}
	}
}
