﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Text;
using System.Web;

namespace Ckode.Bitly.Net.Request
{
	internal abstract class HttpRequest
	{
		public string Url { get; set; }
		private readonly IList<KeyValuePair<string, string>> parameters;

		protected HttpRequest()
		{
			parameters = new List<KeyValuePair<string, string>>();
		}

		public string SendRequest()
		{
			if (string.IsNullOrEmpty(Url))
				throw new InvalidOperationException("Cannot send request before Url has been set. It's currently null or empty.");

			var request = CreateRequest();

			using (var response = request.GetResponse())
			{
				using (var responseStream = response.GetResponseStream())
				{
					using (var reader = new StreamReader(responseStream))
					{
						return reader.ReadToEnd();
					}
				}
			}
		}

		public void AddParameter(string key, string value)
		{
			parameters.Add(new KeyValuePair<string, string>(key, value));
		}

		protected abstract WebRequest CreateRequest();

		protected string BuildParameterString()
		{
			var builder = new StringBuilder();
			foreach (var pair in parameters)
			{
				builder.Append("&" + HttpUtility.UrlEncode(pair.Key) + "=" + HttpUtility.UrlEncode(pair.Value));
			}
			builder.Remove(0, 1); // Removes first ampersand (&)
			return builder.ToString();
		}
	}
}
