﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Results;

namespace Ckode.Bitly.Net.ResultParsers
{
	internal class AuthenticateResultParser : IResultParser<AuthenticateResult>
	{
		public AuthenticateResult Parse(string rawResult)
		{
			var baseParser = new BaseResultParser(rawResult, this);
			var dataElement = baseParser.GetDataElement();
			var authenticateElement = dataElement.Element("authenticate");

			if (authenticateElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "authenticate", rawResult);

			var successfulElement = authenticateElement.Element("successful");
			if (successfulElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "successful", rawResult);

			var successful = successfulElement.Value == "1";
			var username = string.Empty;
			var apikey = string.Empty;
			if (successful)
			{
				var usernameElement = authenticateElement.Element("username");
				if (usernameElement == null)
					throw ExceptionFactory.CreateElementNotFoundException(Function, "username", rawResult);
				
				username = usernameElement.Value;


				var apikeyElement = authenticateElement.Element("api_key");
				if (apikeyElement == null)
					throw ExceptionFactory.CreateElementNotFoundException(Function, "api_key", rawResult);
				
				apikey = apikeyElement.Value;
			}
			return new AuthenticateResult(username, apikey, successful);
		}

		public FunctionName Function
		{
			get { return FunctionName.Authenticate; }
		}
	}
}
