﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Xml.Linq;
using Ckode.Bitly.Net.Exceptions;

namespace Ckode.Bitly.Net.ResultParsers
{
	internal sealed class BaseResultParser
	{
		private readonly XElement responseElement;
		private readonly FunctionName function;
		public BaseResultParser(string rawResult, IResultParser parser)
		{
			function = parser.Function;
			var document = XDocument.Parse(rawResult);
			responseElement = document.Element("response");
			if (responseElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(function, "response", rawResult);

			var statusCodeElement = responseElement.Element("status_code");
			var statusTextElement = responseElement.Element("status_txt");

			if (statusCodeElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(function, "status_code", rawResult);

			if (statusTextElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(function, "status_txt", rawResult);


			ValidateStatusCode(statusCodeElement.Value, statusTextElement.Value);
		}
		/// <summary>
		/// Validates the status code, and throws a BitlyResultException if it's not OK.
		/// </summary>
		/// <param name="statusCode">statusCode to validate.</param>
		/// <param name="statusText">Accompanying statusText, which clarifies the statusCode.</param>
		private void ValidateStatusCode(string statusCode, string statusText)
		{
			if (statusCode != "200")
				throw ExceptionFactory.CreateHttpErrorException(function, statusCode, statusText);
		}

		public XElement GetDataElement()
		{
			return responseElement.Element("data");
		}
	}
}
