﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Collections.Generic;
using System.Linq;
using System.Xml.Linq;
using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Results;

namespace Ckode.Bitly.Net.ResultParsers
{
	internal class ClicksResultParser : IResultParser<IEnumerable<ClicksResult>>
	{
		public IEnumerable<ClicksResult> Parse(string rawResult)
		{
			var baseParser = new BaseResultParser(rawResult, this);
			var dataElement = baseParser.GetDataElement();

			var result = from entryElement in dataElement.Elements("clicks")
						 select ParseEntry(entryElement, rawResult);
			return result;
		}

		private ClicksResult ParseEntry(XContainer entryElement, string rawResult)
		{
			var errorElement = entryElement.Element("error");
			var shortUrlElement = entryElement.Element("short_url");
			var hashElement = entryElement.Element("hash");
			var globalHashElement = entryElement.Element("global_hash");
			var userHashElement = entryElement.Element("user_hash");
			if (errorElement != null)
			{
				if (shortUrlElement != null)
					throw ExceptionFactory.CreateFunctionErrorWithShortUrl(Function, shortUrlElement.Value, errorElement.Value);
				if (hashElement != null)
					throw ExceptionFactory.CreateFunctionErrorWithHash(Function, hashElement.Value, errorElement.Value);

				throw ExceptionFactory.CreateFunctionErrorWithMissingElements(Function, errorElement.Value);
			}

			var globalClicksElement = entryElement.Element("global_clicks");
			var userClicksElement = entryElement.Element("user_clicks");

			if (globalClicksElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "global_clicks", rawResult);

			if (userClicksElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "user_clicks", rawResult);

			return new ClicksResult()
			{
				ShortUrl = shortUrlElement != null ? shortUrlElement.Value : null,
				Hash = hashElement != null ? hashElement.Value : null,
				GlobalHash = globalHashElement.Value,
				UserHash = userHashElement.Value,
				GlobalClicks = int.Parse(globalClicksElement.Value),
				UserClicks = int.Parse(userClicksElement.Value)
			};
		}

		public FunctionName Function
		{
			get { return FunctionName.Clicks; }
		}
	}
}
