﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Collections.Generic;
using System.Linq;
using System.Xml.Linq;
using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Results;

namespace Ckode.Bitly.Net.ResultParsers
{
	internal class ExpandResultParser : IResultParser<IEnumerable<ExpandResult>>
	{
		public IEnumerable<ExpandResult> Parse(string rawResult)
		{
			var baseParser = new BaseResultParser(rawResult, this);
			var dataElement = baseParser.GetDataElement();

			var result = from entryElement in dataElement.Elements("entry")
						 select ParseEntry(entryElement);
			return result;
		}

		private ExpandResult ParseEntry(XElement entryElement)
		{
			var errorElement = entryElement.Element("error");
			var shortUrlElement = entryElement.Element("short_url");
			var hashElement = entryElement.Element("hash");
			var globalHashElement = entryElement.Element("global_hash");
			var userHashElement = entryElement.Element("user_hash");
			var longUrlElement = entryElement.Element("long_url");
			if (errorElement != null)
			{
				if (shortUrlElement != null)
					throw ExceptionFactory.CreateFunctionErrorWithShortUrl(Function, shortUrlElement.Value, errorElement.Value);
				else
					throw ExceptionFactory.CreateFunctionErrorWithShortUrl(Function, hashElement.Value, errorElement.Value);
			}

			return new ExpandResult()
			{
				ShortUrl = shortUrlElement != null ? shortUrlElement.Value : null,
				Hash = hashElement != null ? hashElement.Value : null,
				GlobalHash = globalHashElement.Value,
				UserHash = userHashElement.Value,
				LongUrl = longUrlElement.Value,
			};
		}

		public FunctionName Function
		{
			get { return FunctionName.Expand; }
		}
	}
}
