﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Collections.Generic;
using System.Linq;
using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Results;

namespace Ckode.Bitly.Net.ResultParsers
{
	internal class LookupResultParser : IResultParser<IEnumerable<LookupResult>>
	{
		public IEnumerable<LookupResult> Parse(string rawResult)
		{
			var baseParser = new BaseResultParser(rawResult, this);
			var dataElement = baseParser.GetDataElement();

			var result = from entryElement in dataElement.Elements("lookup")
						 select ParseEntry(entryElement, rawResult);
			return result;
		}

		private LookupResult ParseEntry(System.Xml.Linq.XElement entryElement, string rawResult)
		{
			var errorElement = entryElement.Element("error");
			var urlElement = entryElement.Element("url");

			if (errorElement != null)
			{
				if (urlElement != null)
					throw ExceptionFactory.CreateFunctionErrorWithLongUrl(Function, urlElement.Value, errorElement.Value);

				throw ExceptionFactory.CreateFunctionErrorWithMissingElements(Function, errorElement.Value);
			}

			if (urlElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "url", rawResult);

			var shortUrlElement = entryElement.Element("short_url");
			var globalHashElement = entryElement.Element("global_hash");

			if (shortUrlElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "short_url", rawResult);

			if (globalHashElement == null)
				throw ExceptionFactory.CreateElementNotFoundException(Function, "global_hash", rawResult);

			return new LookupResult()
			{
				GlobalHash = globalHashElement.Value,
				ShortUrl = shortUrlElement.Value,
				Url = urlElement.Value
			};
		}

		public FunctionName Function
		{
			get { return FunctionName.Lookup; }
		}
	}
}
