﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System.Collections.Generic;
using System.Linq;
using System.Xml.Linq;
using Ckode.Bitly.Net.Exceptions;
using Ckode.Bitly.Net.Results;

namespace Ckode.Bitly.Net.ResultParsers
{
	internal class ReferrersResultParser : IResultParser<ReferrersResult>
	{
		public ReferrersResult Parse(string rawResult)
		{
			var baseParser = new BaseResultParser(rawResult, this);
			var dataElement = baseParser.GetDataElement();

			var result = ParseEntry(dataElement, rawResult);
			result.Referrers = from entryElement in dataElement.Elements("referrers")
						 select ParseStatEntry(entryElement, rawResult);
			
			return result;
		}

		private ReferrersResult ParseEntry(XElement entryElement, string rawResult)
		{
			var errorElement = entryElement.Element("error");
			var shortUrlElement = entryElement.Element("short_url");
			var hashElement = entryElement.Element("hash");
			var globalHashElement = entryElement.Element("global_hash");
			var userHashElement = entryElement.Element("user_hash");
			if (errorElement != null)
			{
				if (shortUrlElement != null)
					throw ExceptionFactory.CreateFunctionErrorWithShortUrl(Function, shortUrlElement.Value, errorElement.Value);
				if (hashElement != null)
					throw ExceptionFactory.CreateFunctionErrorWithHash(Function, hashElement.Value, errorElement.Value);

				throw ExceptionFactory.CreateFunctionErrorWithMissingElements(Function, errorElement.Value);
			}

			return new ReferrersResult()
			{
				ShortUrl = shortUrlElement != null ? shortUrlElement.Value : null,
				Hash = hashElement != null ? hashElement.Value : null,
				GlobalHash = globalHashElement.Value,
				UserHash = userHashElement.Value,
			};
		}

		private ReferrerStats ParseStatEntry(XContainer entryElement, string rawResult)
		{
			var referrerElement = entryElement.Element("referrer");
			var referrerAppElement = entryElement.Element("referrer_app");

			if (referrerElement == null && referrerAppElement == null)
				throw ExceptionFactory.CreateMultipleElementsNotFoundException(Function, new[] { "referrer", "referrer_app" }, rawResult);

			var clicksElement = entryElement.Element("clicks");
			var urlElement = entryElement.Element("url");

			return new ReferrerStats()
			{
				Referrer = referrerElement != null ? referrerElement.Value : null,
				ReferrerApp = referrerAppElement != null ? referrerAppElement.Value : null,
				Clicks = int.Parse(clicksElement.Value),
				Url = urlElement != null ? urlElement.Value : null
			};
		}

		public FunctionName Function
		{
			get { return FunctionName.Referrers; }
		}
	}
}
