﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Ckode.Bitly.Net.Results
{
	public class ShortenResult
	{
		/// <summary>
		/// Designates if this is the first time this long_url was shortened . The return value will equal true the first time a long_url is shortened. It will also then be added to the user history.
		/// </summary>
		public bool NewHash { get; internal set; }

		/// <summary>
		/// The actual link that should be used, and is a unique value for the given bit.ly account.
		/// </summary>
		public string Url { get; internal set; }

		/// <summary>
		/// A bit.ly identifier for long_url which is unique to the given account.
		/// </summary>
		public string Hash { get; internal set; }

		/// <summary>
		/// A bit.ly identifier for long_url which can be used to track aggregate stats across all matching bit.ly links.
		/// </summary>
		public string GlobalHash { get; internal set; }

		/// <summary>
		/// an echo back of the longUrl request parameter. This may not always be equal to the URL requested. That's because some URL normalization may occur (e.g., due to encoding differences, or case differences in the domain).
		/// This long_url will always be functionally identical the the request parameter.
		/// </summary>
		public string LongUrl { get; internal set; }

		internal ShortenResult()
		{
		}
	}
}
