﻿/*
 *  Bitly.Net is a Dot.Net wrapper around the bit.ly RESTful API. bit.ly is an URL shortening service located at http://bit.ly
 *  Copyright (C) 2010 Ckode.dk

 *  This file is part of Bitly.Net.

 *  Bitly.Net is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Bitly.Net is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Bitly.Net.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using Ckode.Bitly.Net.Validation.Validators;

namespace Ckode.Bitly.Net.Validation
{
    internal class Validator : IValidator
    {
        public bool IsValidUrl(string url)
        {
            var urlValidator = new UrlValidator();
            return urlValidator.IsValid(url);
        }

        public bool IsValidShortUrl(string shortUrl)
        {
            if (!IsValidUrl(shortUrl))
                return false;
            
            UriBuilder uri = new UriBuilder(shortUrl);
            var domainValidator = new DomainValidator();
            return domainValidator.IsValid(uri.Host);
        }

        public bool IsValidHash(string hash)
        {
            var hashValidator = new HashValidator();
            return hashValidator.IsValid(hash);
        }


        public bool IsValidDomain(string domain, bool allowEmpty)
        {
            if (allowEmpty && string.IsNullOrEmpty(domain)) // meaning default
                return true;

            var domainValidator = new DomainValidator();
            return domainValidator.IsValid(domain);
        }

        public bool IsValidXUser(string login, string apiKey)
        {
            return string.IsNullOrEmpty(login) == string.IsNullOrEmpty(apiKey);
        }

        public bool IsValidLogin(string login)
        {
            return !string.IsNullOrEmpty(login);
        }

        public bool IsValidApiKey(string apiKey)
        {
            return !string.IsNullOrEmpty(apiKey);
        }
    }
}
